.. pygsl documentation master file, created by
   sphinx-quickstart on Thu Aug 10 14:17:26 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

#################################
Welcome to pygsl's documentation!
#################################

.. toctree::
   :maxdepth: 8
   :caption: Contents:

   ref/ref
   ref/interfacedesign
   api/pygsl
   ref/freedoc

##################
Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
